@@ -3,6 +3,18 @@
  * Copyright (c) 1997-2001  Jonathan A. Buzzard (jonathan@buzzard.org.uk)
  *
  * $Log: hotkey.c,v $
+ * Revision 2.9  2001/11/19 17:33:15  jab
+ * added a switch to root so we do not hold mount points open
+ *
+ * Revision 2.8  2001/10/31 14:47:42  jab
+ * updated so kernel module cannot be unloaded when running
+ *
+ * Revision 2.7  2001/10/05 13:02:38  jab
+ * removed #include"toshiba.h"
+ *
+ * Revision 2.6  2001/03/21 13:39:29  jab
+ * fixed bug with commandline locale support
+ *
  * Revision 2.5  2001/02/02 17:09:00  jab
  * added notice about kernel module to error message
  * moved the lock file to /var/tmp
@@ -68,7 +80,7 @@
  *
  */
 
-static char const rcsid[]="$Id: hotkey.c,v 2.5 2001/02/02 17:09:00 jab Exp jab $";
+static char const rcsid[]="$Id: hotkey.c,v 2.9 2001/11/19 17:33:15 jab Exp jab $";
 
 
 #include<stdio.h>
@@ -89,7 +101,6 @@ static char const rcsid[]="$Id: hotkey.c,v 2.5 2001/02/02 17:09:00 jab Exp jab $
 
 
 #include"hotkey.h"
-#include"toshiba.h"
 #include"sci.h"
 
 
@@ -109,6 +120,7 @@ static GC gc;
 static XFontSet font;
 static unsigned long pixels[14];
 static int depth = 0;
+static FILE *str;
 
 
 #define FONT "-adobe-helvetica-bold-r-normal-*-12-*-*-*-*-*-*-*,\
@@ -466,6 +478,8 @@ void catch(int x)
 
 	unlink(PID_FILE);
 
+	fclose(str);
+
 	exit(x);
 
 	return;
@@ -476,7 +490,6 @@ int main(int argc, char *argv[])
 {
 	int count,key,loop,refresh,pid,version;
 	long mask;
-	FILE *str;
 	XEvent event;
 	XColor color;
 	char **list,*def_string,*locale,buffer[64];
@@ -546,7 +559,7 @@ int main(int argc, char *argv[])
 
 	if (--argc>0) {
 		argv++;
-		if (strcmp(argv[0], "-display")) {
+		if (!strcmp(argv[0], "-display")) {
 			if (argc<=1) {
 				printf(USAGE);
 				unlink(PID_FILE);
@@ -713,6 +726,15 @@ int main(int argc, char *argv[])
 	refresh = 0;
 	type = GetModelType();
 
+	/* switch to root so we do not hold mount points open */
+
+	chdir("/");
+
+	/* open /proc/toshiba for reading */
+
+	if (!(str = fopen(TOSH_PROC, "r")))
+		return -1;
+
 	/* loop forever */
 
 	for (;;) {
@@ -723,13 +745,13 @@ int main(int argc, char *argv[])
 
 		/* open /proc/toshiba for reading */
 
+		fclose(str);
 		if (!(str = fopen(TOSH_PROC, "r")))
 			return -1;
 
 		/* scan in Fn key information */
 
 		fgets(buffer, sizeof(buffer)-1, str);
-		fclose(str);
 		buffer[sizeof(buffer)-1] = '\0';
 		sscanf(buffer, "%*s %*x %*d.%*d %*d.%*d %*x %x\n", &key);
 
@@ -780,5 +802,7 @@ int main(int argc, char *argv[])
 		}
 	}
 
+	fclose(str);
+
 	return 0;
 }
