@@ -90,7 +90,7 @@ static struct MachineSettings machine;
 static int powermode,source;
 static int hours,minutes,alarmformat;
 static unsigned short alarmon;
-static int lcdtype,savetype;
+static int lcdtype,savetype,cooltype;
 
 GtkWidget *battery,*hdd,*display,*autooff;
 GtkWidget *speed,*sleep,*lcd,*cooling,*standby;
@@ -125,7 +125,7 @@ void SetSystemOptions(void);
 
 
 enum { STOCKHOLM, ATLANTA, MAUI, LIBRETTO };
-enum { BRIGHT, SUPER, BACKLIGHT };
+enum { HIGHLOW, BRIGHT, SUPER, BACKLIGHT };
 
 #define RESUME_DEPENDENCY \
 "The System Auto Off feature is only functional\n\
@@ -251,6 +251,15 @@ static MenuItem sleepmenu[] =
 	{NULL, NULL, NULL, NULL}
 };
 
+
+static MenuItem lcdhighlowmenu[] =
+{
+	{"Low", LCDCallback, (gpointer) SCI_LOW, NULL},
+	{"High", LCDCallback, (gpointer) SCI_HIGH, NULL},
+	{NULL, NULL, NULL, NULL}
+};
+
+
 static MenuItem lcdbrightmenu[] =
 {
 	{"Bright", LCDCallback, (gpointer) SCI_BRIGHT, NULL},
@@ -424,7 +433,8 @@ void SetBatterySensitivity(int save)
 		gtk_widget_set_sensitive(GTK_WIDGET(speed), TRUE);
 		gtk_widget_set_sensitive(GTK_WIDGET(sleep), TRUE);
 		gtk_widget_set_sensitive(GTK_WIDGET(lcd), TRUE);
-		gtk_widget_set_sensitive(GTK_WIDGET(cooling), TRUE);
+		if (cooltype==TRUE)
+			gtk_widget_set_sensitive(GTK_WIDGET(cooling), TRUE);
 	} else {
 		gtk_widget_set_sensitive(GTK_WIDGET(hdd), FALSE);
 		gtk_widget_set_sensitive(GTK_WIDGET(display), FALSE);
@@ -432,7 +442,8 @@ void SetBatterySensitivity(int save)
 		gtk_widget_set_sensitive(GTK_WIDGET(speed), FALSE);
 		gtk_widget_set_sensitive(GTK_WIDGET(sleep), FALSE);
 		gtk_widget_set_sensitive(GTK_WIDGET(lcd), FALSE);
-		gtk_widget_set_sensitive(GTK_WIDGET(cooling), FALSE);
+		if (cooltype==TRUE)
+			gtk_widget_set_sensitive(GTK_WIDGET(cooling), FALSE);
 	}
 
 	return;
@@ -515,8 +526,10 @@ void SetBatteryOptions(int mode)
 			gtk_option_menu_set_history(GTK_OPTION_MENU(lcd), i);
 	}
 
-	if ((i = GetMenuItemNumber(coolingmenu, settings.cooling))!=-1)
-		gtk_option_menu_set_history(GTK_OPTION_MENU(cooling), i);
+	if (cooltype==TRUE) {
+		if ((i = GetMenuItemNumber(coolingmenu, settings.cooling))!=-1)
+			gtk_option_menu_set_history(GTK_OPTION_MENU(cooling), i);
+	}
 
 
 	/* we are done so set the enable/disable the option menus as needed */
@@ -935,7 +948,7 @@ void MachineDefaultsCallback(GtkWidget *widget, gpointer *data)
 void AddBatteryPage(GtkWidget *notebook, GtkWidget *window)
 {
 	SMMRegisters reg;
-	int placement;
+	int placement,size;
 	GtkWidget *box,*frame,*buttons,*options;
 	GtkWidget *label,*operation,*button,*table;
 	GtkWidget *menu;
@@ -995,6 +1008,23 @@ void AddBatteryPage(GtkWidget *notebook, GtkWidget *window)
 		if ((reg.ebx & 0xffff)==0x0000)
 			lcdtype = BRIGHT;
 	}
+	reg.ebx = SCI_LCD_MAXBRIGHT;
+	if (GetSetting(&reg, ERROR_NONE)==SCI_SUCCESS) {
+		lcdtype = HIGHLOW;
+		if (external.lcd>1)
+			external.lcd = 1;
+		if (internal.lcd>1)
+			internal.lcd = 1;
+	}
+
+	/* check to make sure that cooling method is supported */
+	reg.ebx = SCI_COOLING_METHOD;
+	if (GetSetting(&reg, ERROR_NONE)==SCI_SUCCESS) {
+		cooltype = TRUE;
+	} else {
+		cooltype = FALSE;
+	}
+
 	
 	/* now create the widgets for the page */
 
@@ -1041,9 +1071,15 @@ void AddBatteryPage(GtkWidget *notebook, GtkWidget *window)
 	gtk_signal_connect(GTK_OBJECT(button), "pressed",
 		GTK_SIGNAL_FUNC(PowerSourceCallback), (gpointer) SCI_MAINS);
 
+
+	/* determine the number of options going to be added */
+	size = 8;
+	if (cooltype==FALSE)
+		size--;
+
 	/* create a table to hold all the option buttons and labels */
 
-	table = gtk_table_new(8, 2, FALSE);
+	table = gtk_table_new(size, 2, FALSE);
 	gtk_container_border_width(GTK_CONTAINER(table), 2);
 	gtk_box_pack_start(GTK_BOX(options), table, TRUE, TRUE, 0);
 
@@ -1099,12 +1135,14 @@ void AddBatteryPage(GtkWidget *notebook, GtkWidget *window)
 		GTK_SHRINK | GTK_FILL | GTK_EXPAND, 0, 2);
 	placement++;
 
-	label = gtk_label_new("Cooling Method");
-	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 1.0);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, placement,
-		placement+1, GTK_SHRINK | GTK_FILL | GTK_EXPAND,
-		GTK_SHRINK | GTK_FILL | GTK_EXPAND, 0, 2);
-	placement++;
+	if (cooltype==TRUE) {
+		label = gtk_label_new("Cooling Method");
+		gtk_misc_set_alignment(GTK_MISC(label), 0.0, 1.0);
+		gtk_table_attach(GTK_TABLE(table), label, 0, 1, placement,
+			placement+1, GTK_SHRINK | GTK_FILL | GTK_EXPAND,
+			GTK_SHRINK | GTK_FILL | GTK_EXPAND, 0, 2);
+		placement++;
+	}
 
 	/* now the option buttons */
 
@@ -1178,6 +1216,8 @@ void AddBatteryPage(GtkWidget *notebook, GtkWidget *window)
 		menu = BuildMenu(lcdbrightmenu);
 	else if (lcdtype==SUPER)
 		menu = BuildMenu(lcdsupermenu);
+	else if (lcdtype==HIGHLOW)
+		menu = BuildMenu(lcdhighlowmenu);
 	else
 		menu = BuildMenu(lcdbackmenu);
 
@@ -1188,13 +1228,15 @@ void AddBatteryPage(GtkWidget *notebook, GtkWidget *window)
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(lcd), menu);
 	placement++;
 
-	menu = BuildMenu(coolingmenu);
-	cooling = gtk_option_menu_new();
-	gtk_table_attach(GTK_TABLE(table), cooling, 1, 2, placement,
-		placement+1, GTK_SHRINK | GTK_FILL | GTK_EXPAND,
-		GTK_SHRINK | GTK_FILL | GTK_EXPAND, 4, 2);
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(cooling), menu);
-	placement++;
+	if (cooltype==TRUE) {
+		menu = BuildMenu(coolingmenu);
+		cooling = gtk_option_menu_new();
+		gtk_table_attach(GTK_TABLE(table), cooling, 1, 2, placement,
+			placement+1, GTK_SHRINK | GTK_FILL | GTK_EXPAND,
+			GTK_SHRINK | GTK_FILL | GTK_EXPAND, 4, 2);
+		gtk_option_menu_set_menu(GTK_OPTION_MENU(cooling), menu);
+		placement++;
+	}
 
 	/* set the option menus to match the current battery save mode */
 
