@@ -1,6 +1,6 @@
 /* ownerstring.c -- view/change the owner string on a Toshiba laptop.
  *
- * Copyright (c) 1998-2000  Jonathan A. Buzzard (jonathan@buzzard.org.uk)
+ * Copyright (c) 1998-2001  Jonathan A. Buzzard (jonathan@buzzard.org.uk)
  *
  * $Log:$
  *
@@ -39,10 +39,10 @@ static const char rcsid[]="$Id:$";
 
 #define USAGE \
 "This utility can be used to set and change the owner string.\n\n\
-Usage: ownerstring [-h|v]\n\
-    without parameters : Display if the supervisor password is registered or\n\
-                         not, and allow to register/delete it.\n\
-    -u : Display the current user password mode and allow it to be changed.\n"
+Usage: ownerstring [-p|r|s]\n\
+    -p : Display the current owner string on stdout.\n\
+    -r : remove the current owener string\n\
+    -s : Set the owener string using the input on stdin.\n"
 
 
 /*
@@ -59,13 +59,17 @@ void Catch(int x)
 
 
 /*
- * Print Incompatiable machine type and exit
+ * check the laptop supports the owner string feature
  */
-void Incompatible()
+int OwnerStringSupport(void)
 {
-	fprintf(stderr, "ownerstring: Incompatiable machine type.\n");
-	unlink(PID_FILE);
-	exit(1);
+	SMMRegisters reg;
+
+	reg.eax = HCI_GET;
+	reg.ebx = HCI_OWNERSTRING;
+	reg.esi = 0x0000;
+
+	return HciFunction(&reg);
 }
 
 
@@ -77,7 +81,7 @@ char *GetOwnerString(void)
 	SMMRegisters reg;
 	char *owner,*string;
 	unsigned long characters;
-	int i,j,c,length,valid;
+	int i,j,c,length;
 
 	/* how big is the current owner string */
 
@@ -86,7 +90,6 @@ char *GetOwnerString(void)
 	reg.esi = 0x0000;
 	HciFunction(&reg);
 	length = (reg.ecx & 0xffff0000)>>16;
-	printf("length=%d\n", length);
 	owner = calloc(length, sizeof(char));
 	if (owner==NULL) {
 		fprintf(stderr, "UNABLE TO MALLOC SPACE");
@@ -100,7 +103,6 @@ char *GetOwnerString(void)
 		reg.eax = HCI_GET;
 		reg.ebx = 0x29;
 		reg.esi = (unsigned long) i;
-		printf("index=%d    ", reg.esi);
 		if (HciFunction(&reg)!=0x00) {
 			fprintf(stdout, "ERROR : reading ownerstring\n");
 			break;
@@ -108,18 +110,16 @@ char *GetOwnerString(void)
 
 		/* add non NULL characters to the string */
 
-		valid = reg.ecx & 0xffff;
-		printf("index=%d  valid=%d\n", reg.esi, valid);
 		characters = reg.edx;
 		for (j=0;j<4;j++) {
 			c = (char) characters & 0xff;
-			printf("%02x ", c);
 			characters = characters >> 8;
 		        if ((c>=0x20) && (c<=0x80))
 				*(string++) = c;
 			if (c==0x0d)
 				*(string++) = c;
-
+			if (c==0x00)
+				*(string++) = c;
 		}
 	}
 	*string = '\0';
@@ -135,30 +135,36 @@ int SetOwnerString(char *owner)
 {
 	SMMRegisters reg;
 	char string[513];
-	int length,i;
+	int i;
 
-	length = strlen(owner);
-	printf("length=%d\n", length);
+	/* copy at most 512 characters of the input string */
 
-	reg.eax = HCI_SET;
-	reg.ebx = HCI_OWNERSTRING;
-	reg.ecx = 4;
-	reg.esi = 0;
-	reg.edx = 0x74736554;
-	reg.edi = 0x54657374;
-	i = HciFunction(&reg);
+	memset(string, 0, sizeof(char));
+	strncpy(string, owner, 512);
 
-	printf("eax=0x%x, ecx=0x%x\n", reg.eax, reg.ecx);
+	/* set the new string */
 
-	/* write zero's into the rest of the owner string */
-
-/*	for (i=1;i<512;i+=4) {
+	for (i=0;i<512;i+=8) {
 		reg.eax = HCI_SET;
-		reg.ecx = 4;
+		reg.ebx = HCI_OWNERSTRING;
+		reg.ecx = 8;
 		reg.esi = i;
-		reg.edx = 0x00000000;
-		HciFunction(&reg);
-	}*/
+
+		reg.edx = (int) string[i];
+		reg.edx |= ((int) string[i+1]) << 8;
+		reg.edx |= ((int) string[i+2]) << 16;
+		reg.edx |= ((int) string[i+3]) << 24;
+		
+		reg.edi = (int) string[i+4];
+		reg.edi |= ((int) string[i+5]) << 8;
+		reg.edi |= ((int) string[i+6]) << 16;
+		reg.edi |= ((int) string[i+7]) << 24;
+
+		if (HciFunction(&reg)!=0x00) {
+			fprintf(stdout, "ERROR : writing ownerstring\n");
+			return 1;
+		}
+	}
 
 	return 0;
 }
@@ -168,31 +174,53 @@ int SetOwnerString(char *owner)
 int main(int argc, char *argv[])
 {
 	FILE *str;
-	int pid,help,version;
-	char *owner;
-	char new[]="Test owner string";
+	int i,pid,version,print,remove,set;
+	char c,*owner,new[513];
 
 
 	/* this program *must* be run as root */
 
-/*	if (getuid()) {
+	if (getuid()) {
 		fprintf(stderr, "ownerstring: must be run as root.\n");
 		return 1;
 	}
-*/
+
+	/* is this a Toshiba laptop? */
+
+	if (SciSupportCheck(&version)==SCI_FAILURE) {
+		fprintf(stderr, "ownerstring: this computer is not supported "
+			"or the kernel module is not installed.\n");
+		return 1;
+	}
+
+	/* check this model supports an owner string */
+
+	if (OwnerStringSupport()!=0x00) {
+		fprintf(stderr, "ownerstring: this computer does not support "
+			"the ownerstring feature.\n");
+		return 1;
+	} 
 
 	/* process command line arguments */
 
- 	help = 0;
-	if ((--argc>0) && ((*++argv)[0]=='-'))
-		switch (*++argv[0]) {
-			case 'h':
-				help = 1;
-				break;
-			default:
-				printf("ownerstring: illegal option %s\n", argv[0]);
-				return 1;
-		}
+	print = 0;
+	set = 0;
+	remove = 0;
+	if (argc==1) {
+		printf(USAGE);
+		return 0;
+	}
+
+	if (!strcmp(argv[1], "-p") || !strcmp(argv[1], "--print")) {
+		print = 1;
+	} else if (!strcmp(argv[1], "-r") || !strcmp(argv[1], "--remove")) {
+		remove = 1;
+	} else if (!strcmp(argv[1], "-s") || !strcmp(argv[1], "--set")) {
+		set = 1;
+	} else {
+		printf("ownerstring: illegal option %s\n", argv[1]);
+		return 1;
+	}
 
 	/* if we recieve a signal, exit cleanly */
 
@@ -235,29 +263,27 @@ int main(int argc, char *argv[])
 		fclose(str);
 	}
 	
-	/* is this a supported machine? */
+	if (print==1) {
+		owner = GetOwnerString();
+		printf("%s\n", owner);
+	} else if (remove==1) {
+		memset(new, 0, sizeof(char)*513);
+		SetOwnerString(new);
+	} else if (set==1) {
+		i = 0;
+		memset(new, 0, sizeof(char)*513);
 
-	if (SciSupportCheck(&version)==SCI_FAILURE)
-		Incompatible();
+		/* read the new owner string from stdin */
 
-	/* did the user request help? */
-
-	if (help==1) {
-		printf(USAGE);
-		unlink(PID_FILE);
-		exit(0);
+		while ((i<512) && ((c=getchar())!=EOF)) {
+			new[i] = c;
+			i++;
+		}
+		
+		SetOwnerString(new);
 	}
 
-	owner = GetOwnerString();
-	printf("%s\n", owner);
-
-/*	SetOwnerString(new);*/
-
-/*	add_history(new);
-	owner = readline(NULL);
-	printf("STRING:\n%s\n", owner);
-*/
-
 	unlink(PID_FILE);
+
 	return 0;
 }
