@@ -11,6 +11,9 @@
  * <dhinds@pcmcia.sourceforge.org>
  *
  * $Log: thotswap.c,v $
+ * Revision 1.6  2001/03/22 14:19:17  jab
+ * make sure err is initialized to fix compiler warning message
+ *
  * Revision 1.5  2001/02/02 17:20:23  jab
  * added notice about kernel module to error message
  * move the lock file when running as a daemon to /var/tmp
@@ -46,7 +49,7 @@
  *
  */
 
-static char const rcsid[]="$Id: thotswap.c,v 1.5 2001/02/02 17:20:23 jab Exp jab $";
+static char const rcsid[]="$Id: thotswap.c,v 1.6 2001/03/22 14:19:17 jab Exp jab $";
 
 
 #include<stdio.h>
@@ -322,6 +325,7 @@ int SelectbayUnregister(void)
 
 	/* request a device in the SelectBay is unregistered */
 
+	err = -1;
 	for (loop=0;loop<2;loop++) {
 		err = ioctl(fd, HDIO_UNREGISTER_HWIF, 1);
 		if (err==0)
@@ -368,6 +372,7 @@ int SelectbayRescan(void)
 
 	/* loop as sometimes it fails for no apparent reason */
 
+	err = -1;
 	for (loop=0;loop<2;loop++) {
 		err = ioctl(fd, HDIO_SCAN_HWIF, args);
 		if (err==0)
