@@ -8,6 +8,19 @@
  *       mount.app by Steve Borho <borho@stlnet.com>
  *
  * $Log: wmtuxtime.c,v $
+ * Revision 1.12  2002/01/27 13:22:40  jab
+ * updated list of machine ID's
+ *
+ * Revision 1.11  2001/10/05 13:02:01  jab
+ * fixed argv cast problem in ProcessComandLine
+ *
+ * Revision 1.10  2001/07/15 08:56:28  jab
+ * added -h and -v command line options plus a few machine ID's
+ *
+ * Revision 1.9  2001/03/21 13:40:35  jab
+ * fixed bug with charging C in combination with low contrast option
+ * fixed display corruption when changing battery
+ *
  * Revision 1.8  2001/02/04 16:39:47  jab
  * added a pile more machine ID's
  * added notice about kernel module to error message
@@ -58,7 +71,7 @@
  *
  */
 
-static char const rcsid[]="$Id: wmtuxtime.c,v 1.8 2001/02/04 16:39:47 jab Exp jab $";
+static char const rcsid[]="$Id: wmtuxtime.c,v 1.12 2002/01/27 13:22:40 jab Exp jab $";
 
 
 #include<stdio.h>
@@ -88,6 +101,22 @@ static char const rcsid[]="$Id: wmtuxtime.c,v 1.8 2001/02/04 16:39:47 jab Exp ja
 #include"hci.h"
 #include"config.h"
 
+#define VERSION_STRING "\
+wmTuxTime version 1.4\n\
+Copyright (c) 1998-2001 Jonathan A. Buzzard <jonathan@buzzard.org.uk>\n"
+
+#define USAGE_STRING "\
+Usage: wmtuxtime [-c] [-n] [-display] [-geometry] [-v] [-h]\n\
+View battery status and set power saving options on a Toshiba laptop\n\n\
+  -c,--contrast      high contrast option for DSTN screens\n\
+  -n,--normal        normal window attributes instead of dock-app\n\
+  -display           specify the X server to contact\n\
+  -geometry          specify the preferred position of the window\n\
+  -h,--help          display this help message\n\
+  -v,--version       display version\n\
+Report bugs to jonathan@buzzard.org.uk\n"
+
+
 
 enum { EMPTY, PRIMARY, AUXILLARY };
 
@@ -147,15 +176,28 @@ void ProcessComandLine(int *argc, char ***argv)
 
 	for (i=1;i<*argc;i++) {
 		if ((!strcmp((*argv)[i], "-c")) || (!strcmp((*argv)[i], "--contrast"))) {
-			for (j=5;j<12;j++)
+			for (j=5;j<11;j++)
 				wmtuxtime_xpm[3][j] = '0';
-			for (j=5;j<12;j++)
+			for (j=5;j<11;j++)
 				wmtuxtime_xpm[4][j] = '0';
-			for (j=5;j<12;j++)
+			for (j=5;j<11;j++)
 				wmtuxtime_xpm[7][j] = '0';
-			for (j=5;j<12;j++)
+			for (j=5;j<11;j++)
 				wmtuxtime_xpm[9][j] = '0';
 		}
+		if ((!strcmp((*argv)[i], "-h")) || (!strcmp((*argv)[i], "--help"))) {
+			printf(USAGE_STRING);
+			SciCloseInterface();
+			unlink(PID_FILE);
+			exit(0);
+		}
+		if ((!strcmp((*argv)[i], "-v")) || (!strcmp((*argv)[i], "--version"))) {
+			printf(VERSION_STRING);
+			SciCloseInterface();
+			unlink(PID_FILE);
+			exit(0);
+		}
+
 	}
 
 	return;
@@ -508,6 +550,12 @@ void PowerChanged(int source, char *file)
 	} else {
 		lcdtype = SCI_LCD_BACKLIGHT;
 	}
+	reg.ebx = SCI_LCD_MAXBRIGHT;
+	if (SciGet(&reg)==SCI_SUCCESS) {
+		lcdtype = SCI_LCD_MAXBRIGHT;
+		if (lcd>1)
+			lcd = 1;
+	}
 
 	/* set the other settings if user mode or new style machine */
 
@@ -765,6 +813,18 @@ void Update(void)
 	hour = SCI_HOUR(time);
 	minute = SCI_MINUTE(time);
 	
+	/* make sure the times are sensible */
+	if (hour<0) {
+		hour = 0;
+		time = -1;
+	}
+
+	if ((minute<0) || (minute>59)) {
+		minute = 0;
+		time = -1;
+	}
+
+	
 	if ((percent>=0) && (time>=0)) {
 		if ((percent<3) && (percent>=0))
 			state = EMERGENCY;
@@ -865,6 +925,13 @@ void Update(void)
 			break;
 	}
 
+	/* make sure the battery percentage is something sensible */
+
+	if (battery<0)
+		battery = 0;
+	if (battery>100)
+		battery = 100;
+
 	copyXPMArea(5, 93, 19, 7, 7, 34);   /* Show Default % */
 	copyXPMArea(66, 4, 49, 9, 7, 21);    /* Show Default Meter */
 	if (battery==100) {
@@ -978,9 +1045,9 @@ int main(int argc, char *argv[])
         setegid(getgid());
 
 	switch (id) {
-		case 0xfc00: /* Satellite 2140CDS/2180CDT */
+		case 0xfc00: /* Satellite 2140CDS/2180CDT/2675DVD */
 		case 0xfc01: /* Satellite 2710xDVD */
-		case 0xfc02: /* Satellite Pro 4270CDT/4300CDT/4340CDT */
+		case 0xfc02: /* Satellite Pro 4270CDT//4280CDT/4300CDT/4340CDT */
 		case 0xfc04: /* Portege 3410CT, 3440CT */
 		case 0xfc08: /* Satellite 2100CDS/CDT 1550CDS */
 		case 0xfc09: /* Satellite 2610CDT, 2650XDVD */
@@ -1005,14 +1072,22 @@ int main(int argc, char *argv[])
 		case 0xfc41: /* T4500 */
 		case 0xfc45: /* T4400SX/SXC */
 		case 0xfc51: /* Satellite 2210CDT, 2770XDVD */
-		case 0xfc52: /* Dynabook Satellite DB60P/4DA */
+		case 0xfc52: /* Satellite 2775DVD, Dynabook Satellite DB60P/4DA */
+		case 0xfc53: /* Portage 7200CT/7220CT, Satellite 4000CDT */
 		case 0xfc54: /* Satellite 2800DVD */
+		case 0xfc56: /* Portage 3480CT */
+		case 0xfc57: /* Satellite 2250CDT*/
+		case 0xfc5a: /* Satellite Pro 4600 */
+		case 0xfc5d: /* Satellite 2805 */
 		case 0xfc5f: /* T3300SL */
+		case 0xfc61: /* Tecra 8200 */
+		case 0xfc64: /* Satellite 1800 */
 		case 0xfc69: /* T1900C */
 		case 0xfc6a: /* T1900 */
 		case 0xfc6d: /* T1850C */
 		case 0xfc6e: /* T1850 */
 		case 0xfc6f: /* T1800 */
+		case 0xfc72: /* Satellite 1800 */
 		case 0xfc7e: /* T4600C */
 		case 0xfc7f: /* T4600 */
 		case 0xfc8a: /* T6600C */
@@ -1036,12 +1111,13 @@ int main(int argc, char *argv[])
 		case 0xfcd0: /* Satellite 300x */
 		case 0xfcd1: /* Tecra 750CDT */
 		case 0xfcd2: /* Vision Connect -- what is this??? */
+		case 0xfcd3: /* Tecra 730XCDT*/
 		case 0xfcd4: /* Tecra 510x */
 		case 0xfcd5: /* Satellite 200x */
 		case 0xfcd7: /* Satellite Pro 430x */
 		case 0xfcd8: /* Tecra 740x */
 		case 0xfcd9: /* Portage 660CDT */
-		case 0xfcda: /* Tecra 730x/730X */
+		case 0xfcda: /* Tecra 730CDT */
 		case 0xfcdb: /* Portage 620CT */
 		case 0xfcdc: /* Portage 650CT */
 		case 0xfcdd: /* Satellite 110x */
